@@ -1,3 +1,5 @@
+import urllib
+
 from django.contrib.auth.models import User
 
 from funkymetrics.tasks import send_event
@@ -26,6 +28,11 @@ def record_event(request_or_user, action, props=None):
         if hasattr(request_or_user, 'COOKIES') is not None:
             identity = request_or_user.COOKIES.get('km_ai', '')
 
+    # URL encode properties
+    if props is not None:
+        for key, val in props.items():
+            props[key] = urllib.quote_plus(val)
+
     # Queue task
     if identity != '':
         send_event.delay(identity, action, props)
